(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     57678,       1231]
NotebookOptionsPosition[     57194,       1214]
NotebookOutlinePosition[     57592,       1230]
CellTagsIndexPosition[     57549,       1227]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
In the first line of the following cell, substitute the \
\[OpenCurlyDoubleQuote]path\[CloseCurlyDoubleQuote] where the \
\"filename.dat\" is located. For example \
data=Import[\[OpenCurlyDoubleQuote]n_7_sigma1_20.dat\[CloseCurlyDoubleQuote]].\
 The visualizer shows the output in three different representations: (1) the \
coronas of the particles, (2) the Delaunay triangulation, and (3) dot-bar \
representations. The last output may be dragged with the cursor to any \
orientation.\
\>", "Section",
 CellChangeTimes->{{3.866521518695582*^9, 3.866521732901033*^9}, {
   3.866521808893025*^9, 3.8665218566724787`*^9}, {3.866522359739398*^9, 
   3.866522366839919*^9}, {3.866565629383018*^9, 3.866565630222124*^9}, {
   3.866565734241663*^9, 3.8665657885603523`*^9}, {3.866685437295986*^9, 
   3.866685605342819*^9}, {3.866685644950976*^9, 3.8666856675046253`*^9}, {
   3.866685731852282*^9, 3.8666857640088663`*^9}, {3.866798973328141*^9, 
   3.86679899746972*^9}, 
   3.867155574679625*^9},ExpressionUUID->"3ba06042-c261-486c-ab9f-\
45f2778dea21"],

Cell[BoxData[{
 RowBox[{"SetDirectory", "[", "\"\<path\>\"", "]"}], "\n", 
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Import", "[", "\"\<filename.dat\>\"", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"parametros", "=", 
   RowBox[{"Take", "[", 
    RowBox[{"data", ",", "10"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"np", "=", 
   RowBox[{"parametros", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"radiospostot", "=", 
   RowBox[{"Take", "[", 
    RowBox[{"data", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"11", "+", "np", "+", "1"}], ",", 
       RowBox[{"Length", "[", "data", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"radios", "=", 
   RowBox[{"Take", "[", 
    RowBox[{"radiospostot", ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"Length", "[", "radiospostot", "]"}], ",", 
       RowBox[{"np", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"posicionestot", "=", 
   RowBox[{"Drop", "[", 
    RowBox[{"radiospostot", ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"Length", "[", "radiospostot", "]"}], ",", 
       RowBox[{"np", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sigma0", "=", 
   RowBox[{"parametros", "[", 
    RowBox[{"[", 
     RowBox[{"2", ",", "1"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sigma1", "=", 
   RowBox[{"parametros", "[", 
    RowBox[{"[", 
     RowBox[{"3", ",", "1"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mc", "=", 
   RowBox[{"parametros", "[", 
    RowBox[{"[", 
     RowBox[{"4", ",", "1"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nfotos", "=", 
   RowBox[{"parametros", "[", 
    RowBox[{"[", 
     RowBox[{"5", ",", "1"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"radioinicial", "=", 
   RowBox[{"parametros", "[", 
    RowBox[{"[", 
     RowBox[{"6", ",", "1"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmax", "=", 
   RowBox[{"parametros", "[", 
    RowBox[{"[", 
     RowBox[{"7", ",", "1"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmin", "=", 
   RowBox[{"parametros", "[", 
    RowBox[{"[", 
     RowBox[{"8", ",", "1"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dt", "=", 
   RowBox[{"parametros", "[", 
    RowBox[{"[", 
     RowBox[{"9", ",", "1"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"deltaang", "=", 
   RowBox[{"parametros", "[", 
    RowBox[{"[", 
     RowBox[{"10", ",", "1"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nt", "=", 
   RowBox[{
    RowBox[{"IntegerPart", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"tmax", "-", "tmin"}], ")"}], "/", "dt"}], "]"}], "+", "1"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<np= \>\"", ",", "np"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<sigma0= \>\"", ",", "sigma0"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<sigma1= \>\"", ",", "sigma1"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<MC steps= \>\"", ",", "mc"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"radio", "[", "ii", "]"}], "=", 
     RowBox[{"radios", "[", 
      RowBox[{"[", 
       RowBox[{"ii", ",", "1"}], "]"}], "]"}]}], ";", 
    RowBox[{
     RowBox[{"pos", "[", "ii", "]"}], "=", 
     RowBox[{"Take", "[", 
      RowBox[{"posicionestot", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"np", "*", "ii"}], "-", "np", "+", "1"}], ",", 
         RowBox[{"np", "*", "ii"}]}], "}"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"r", "[", "i", "]"}], "=", 
       RowBox[{
        RowBox[{"pos", "[", "ii", "]"}], "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "np"}], "}"}]}], "]"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"energia", "[", "ii", "]"}], "=", "0"}], ";", 
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Norm", "[", 
          RowBox[{
           RowBox[{"r", "[", "i", "]"}], "-", 
           RowBox[{"r", "[", "j", "]"}]}], "]"}], "\[LessEqual]", "sigma1"}], 
        ",", 
        RowBox[{
         RowBox[{"energia", "[", "ii", "]"}], "+=", "1"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "np"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "1", ",", 
        RowBox[{"i", "-", "1"}]}], "}"}]}], "]"}], ";", "\n", 
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"ramas", "[", 
         RowBox[{"ii", ",", "i"}], "]"}], "=", "0"}], ";", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Norm", "[", 
             RowBox[{
              RowBox[{"r", "[", "i", "]"}], "-", 
              RowBox[{"r", "[", "j", "]"}]}], "]"}], "\[LessEqual]", 
            "sigma1"}], ",", 
           RowBox[{
            RowBox[{"ramas", "[", 
             RowBox[{"ii", ",", "i"}], "]"}], "+=", "1"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "1", ",", 
           RowBox[{"i", "-", "1"}]}], "}"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "np"}], "}"}]}], "]"}], ";", "\n", 
    RowBox[{
     RowBox[{"core", "[", "ii", "]"}], "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Sphere", "[", 
        RowBox[{
         RowBox[{"r", "[", "i", "]"}], ",", 
         RowBox[{"sigma0", "/", "2"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "np"}], "}"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"corona", "[", "ii", "]"}], "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Sphere", "[", 
        RowBox[{
         RowBox[{"r", "[", "i", "]"}], ",", 
         RowBox[{"sigma1", "/", "2"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "np"}], "}"}]}], "]"}]}]}], "\n", ",", 
   RowBox[{"{", 
    RowBox[{"ii", ",", "1", ",", 
     RowBox[{
      RowBox[{"Length", "[", "posicionestot", "]"}], "/", "np"}], ",", "1"}], 
    "}"}]}], "]"}], "\n", 
 RowBox[{
  RowBox[{"listaenergia", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"radio", "[", "ii", "]"}], ",", 
       RowBox[{"energia", "[", "ii", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"ii", ",", "1", ",", 
       RowBox[{
        RowBox[{"Length", "[", "posicionestot", "]"}], "/", "np"}]}], "}"}]}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Animate", "[", 
  RowBox[{
   RowBox[{"GraphicsGrid", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Graphics3D", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"RGBColor", "[", 
                 RowBox[{"0", ",", "0.5", ",", "0"}], "]"}], ",", 
                RowBox[{"Opacity", "[", "0.02", "]"}], ",", 
                RowBox[{"Sphere", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
                  RowBox[{"radio", "[", "ii", "]"}]}], "]"}]}], "}"}], ",", 
              RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
              RowBox[{"PlotLabel", "\[Rule]", 
               RowBox[{"Row", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<Particles=\>\"", ",", "np"}], "}"}], "]"}]}]}], 
             "]"}], ",", 
            RowBox[{"Graphics3D", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"RGBColor", "[", 
                 RowBox[{"0", ",", "0.5", ",", "1"}], "]"}], ",", 
                RowBox[{"corona", "[", "ii", "]"}]}], "}"}], ",", 
              RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}]}], "\n", "}"}], 
          ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "radioinicial"}], "-", 
                RowBox[{"sigma1", "/", "2"}]}], ",", 
               RowBox[{"radioinicial", "+", 
                RowBox[{"sigma1", "/", "2"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "radioinicial"}], "-", 
                RowBox[{"sigma1", "/", "2"}]}], ",", 
               RowBox[{"radioinicial", "+", 
                RowBox[{"sigma1", "/", "2"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "radioinicial"}], "-", 
                RowBox[{"sigma1", "/", "2"}]}], ",", 
               RowBox[{"radioinicial", "+", 
                RowBox[{"sigma1", "/", "2"}]}]}], "}"}]}], "}"}]}], ",", 
          RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
          RowBox[{"Epilog", "->", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Text", "[", 
              RowBox[{"TextGrid", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"\"\<Step:\>\"", ",", "ii"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"\"\<Radius:\>\"", ",", 
                   RowBox[{"radio", "[", "ii", "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"\"\<Energy:\>\"", ",", 
                   RowBox[{"energia", "[", "ii", "]"}]}], "}"}]}], "}"}], 
               "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"Left", ",", "Top"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"Left", ",", "Top"}], "}"}]}], "]"}]}]}], "]"}], ",", 
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{"ListPlot", "[", 
           RowBox[{"listaenergia", ",", 
            RowBox[{"Frame", "\[Rule]", "True"}], ",", 
            RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
            RowBox[{"FrameLabel", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"Radius", ",", "Energy"}], "}"}]}]}], "]"}], ",", 
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"PointSize", "[", "Large", "]"}], ",", 
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{
                  {GrayLevel[0], RectangleBox[{0, 0}]}, 
                  {GrayLevel[0], RectangleBox[{1, -1}]}, 
                  {RGBColor[0.922526, 0.385626, 0.209179], 
                   RectangleBox[{0, -1}, {2, 1}]}},
                 AspectRatio->1,
                 Frame->True,
                 
                 FrameStyle->RGBColor[
                  0.6150173333333333, 0.25708400000000003`, 
                   0.13945266666666667`],
                 FrameTicks->None,
                 
                 ImageSize->
                  Dynamic[{
                   Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                 PlotRangePadding->None],
                "RGBColor[0.922526, 0.385626, 0.209179]"],
               Appearance->None,
               BaseStyle->{},
               BaselinePosition->Baseline,
               ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[0.922526, 0.385626, 0.209179]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
               DefaultBaseStyle->{},
               Evaluator->Automatic,
               Method->"Preemptive"],
              RGBColor[0.922526, 0.385626, 0.209179],
              Editable->False,
              Selectable->False], ",", 
             RowBox[{"Point", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"radio", "[", "ii", "]"}], ",", 
                RowBox[{"energia", "[", "ii", "]"}]}], "}"}], "]"}]}], "}"}], 
           "]"}]}], "]"}]}], "}"}], "}"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"870", ",", "400"}], "}"}]}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"ii", ",", "1", ",", 
     FractionBox[
      RowBox[{"Length", "[", "posicionestot", "]"}], "np"], ",", "1", ",", 
     RowBox[{"AppearanceElements", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<ProgressSlider\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
        "\"\<StepRightButton\>\"", ",", "\"\<PlayPauseButton\>\"", ",", 
        "\"\<FasterSlowerButtons\>\"", ",", "\"\<DirectionButton\>\""}], 
       "}"}]}]}], "}"}], ",", 
   RowBox[{"AnimationRunning", "\[Rule]", "False"}], ",", 
   RowBox[{"DisplayAllSteps", "\[Rule]", "True"}]}], "]"}], "\n", 
 RowBox[{"Animate", "[", 
  RowBox[{
   RowBox[{"GraphicsGrid", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"DelaunayMesh", "[", 
            RowBox[{
             RowBox[{"pos", "[", "ii", "]"}], ",", 
             RowBox[{"PlotTheme", "\[Rule]", "\"\<LargeMesh\>\""}]}], "]"}], 
           "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "radioinicial"}], "-", 
                RowBox[{"sigma1", "/", "2"}]}], ",", 
               RowBox[{"radioinicial", "+", 
                RowBox[{"sigma1", "/", "2"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "radioinicial"}], "-", 
                RowBox[{"sigma1", "/", "2"}]}], ",", 
               RowBox[{"radioinicial", "+", 
                RowBox[{"sigma1", "/", "2"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "radioinicial"}], "-", 
                RowBox[{"sigma1", "/", "2"}]}], ",", 
               RowBox[{"radioinicial", "+", 
                RowBox[{"sigma1", "/", "2"}]}]}], "}"}]}], "}"}]}], ",", 
          RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
          RowBox[{"Epilog", "->", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Text", "[", 
              RowBox[{"TextGrid", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"\"\<Step:\>\"", ",", "ii"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"\"\<Radius:\>\"", ",", 
                   RowBox[{"radio", "[", "ii", "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"\"\<Energy:\>\"", ",", 
                   RowBox[{"energia", "[", "ii", "]"}]}], "}"}]}], "}"}], 
               "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"Left", ",", "Top"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"Left", ",", "Top"}], "}"}]}], "]"}]}], ",", 
          RowBox[{"PlotLabel", "\[Rule]", 
           RowBox[{"Row", "[", 
            RowBox[{"{", 
             RowBox[{"\"\<Particles=\>\"", ",", "np"}], "}"}], "]"}]}]}], 
         "]"}], ",", 
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{"ListPlot", "[", 
           RowBox[{"listaenergia", ",", 
            RowBox[{"Frame", "\[Rule]", "True"}], ",", 
            RowBox[{"FrameLabel", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"Radius", ",", "Energy"}], "}"}]}]}], "]"}], ",", 
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"PointSize", "[", "Large", "]"}], ",", 
             InterpretationBox[
              ButtonBox[
               TooltipBox[
                GraphicsBox[{
                  {GrayLevel[0], RectangleBox[{0, 0}]}, 
                  {GrayLevel[0], RectangleBox[{1, -1}]}, 
                  {RGBColor[0.922526, 0.385626, 0.209179], 
                   RectangleBox[{0, -1}, {2, 1}]}},
                 AspectRatio->1,
                 Frame->True,
                 
                 FrameStyle->RGBColor[
                  0.6150173333333333, 0.25708400000000003`, 
                   0.13945266666666667`],
                 FrameTicks->None,
                 
                 ImageSize->
                  Dynamic[{
                   Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                 PlotRangePadding->None],
                "RGBColor[0.922526, 0.385626, 0.209179]"],
               Appearance->None,
               BaseStyle->{},
               BaselinePosition->Baseline,
               ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                 If[
                  Not[
                   AbsoluteCurrentValue["Deployed"]], 
                  SelectionMove[Typeset`box$, All, Expression]; 
                  FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                  FrontEnd`Private`$ColorSelectorInitialColor = 
                   RGBColor[0.922526, 0.385626, 0.209179]; 
                  FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                  MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
               DefaultBaseStyle->{},
               Evaluator->Automatic,
               Method->"Preemptive"],
              RGBColor[0.922526, 0.385626, 0.209179],
              Editable->False,
              Selectable->False], ",", 
             RowBox[{"Point", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"radio", "[", "ii", "]"}], ",", 
                RowBox[{"energia", "[", "ii", "]"}]}], "}"}], "]"}]}], "}"}], 
           "]"}]}], "]"}]}], "}"}], "}"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"870", ",", "400"}], "}"}]}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"ii", ",", "1", ",", 
     FractionBox[
      RowBox[{"Length", "[", "posicionestot", "]"}], "np"], ",", "1", ",", 
     RowBox[{"AppearanceElements", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<ProgressSlider\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
        "\"\<StepRightButton\>\"", ",", "\"\<PlayPauseButton\>\"", ",", 
        "\"\<FasterSlowerButtons\>\"", ",", "\"\<DirectionButton\>\""}], 
       "}"}]}]}], "}"}], ",", 
   RowBox[{"AnimationRunning", "\[Rule]", "False"}], ",", 
   RowBox[{"DisplayAllSteps", "\[Rule]", "True"}]}], "]"}], "\n", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"radio", "[", "ii", "]"}], " ", "=", " ", 
     RowBox[{"radios", "[", 
      RowBox[{"[", 
       RowBox[{"ii", ",", "1"}], "]"}], "]"}]}], ";", " ", 
    RowBox[{
     RowBox[{"pos", "[", "ii", "]"}], " ", "=", " ", 
     RowBox[{"Take", "[", 
      RowBox[{"posicionestot", ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"ii", "*", "np"}], " ", "-", " ", "np", " ", "+", " ", 
          "1"}], ",", " ", 
         RowBox[{"ii", "*", "np"}]}], "}"}]}], "]"}]}], ";", " ", 
    RowBox[{"tablatube", " ", "=", " ", 
     RowBox[{"{", "}"}]}], ";", " ", "\n", "   ", 
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"r", "[", "i", "]"}], " ", "=", " ", 
       RowBox[{
        RowBox[{"pos", "[", "ii", "]"}], "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"i", ",", " ", "1", ",", " ", "np"}], "}"}]}], "]"}], ";", " ", 
    RowBox[{
     RowBox[{"energia", "[", "ii", "]"}], " ", "=", " ", "0"}], ";", " ", 
    "\n", "   ", 
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Norm", "[", 
          RowBox[{
           RowBox[{"r", "[", "i", "]"}], " ", "-", " ", 
           RowBox[{"r", "[", "j", "]"}]}], "]"}], " ", "<=", " ", "sigma1"}], 
        ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"energia", "[", "ii", "]"}], " ", "+=", " ", "1"}], ",", 
          " ", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"tablatube", ",", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"r", "[", "i", "]"}], ",", " ", 
              RowBox[{"r", "[", "j", "]"}]}], "}"}]}], "]"}]}], "}"}]}], 
       "]"}], ",", " ", "\n", "    ", 
      RowBox[{"{", 
       RowBox[{"i", ",", " ", "1", ",", " ", "np"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"j", ",", " ", "1", ",", " ", 
        RowBox[{"i", " ", "-", " ", "1"}]}], "}"}]}], "]"}], ";", " ", 
    RowBox[{
     RowBox[{"coresmall", "[", "ii", "]"}], " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Sphere", "[", 
        RowBox[{
         RowBox[{"r", "[", "i", "]"}], ",", " ", 
         RowBox[{"sigma0", "/", "8"}]}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", " ", "1", ",", " ", "np"}], "}"}]}], "]"}]}], ";", 
    " ", "\n", "   ", 
    RowBox[{
     RowBox[{"coronasmall", "[", "ii", "]"}], " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Sphere", "[", 
        RowBox[{
         RowBox[{"r", "[", "i", "]"}], ",", " ", 
         RowBox[{"sigma0", "/", "10"}]}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", " ", "1", ",", " ", "np"}], "}"}]}], "]"}]}], ";", 
    " ", "\n", "   ", 
    RowBox[{
     RowBox[{"tubos", "[", "ii", "]"}], " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Tube", "[", 
        RowBox[{
         RowBox[{"tablatube", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", " ", 
         RowBox[{"sigma0", "/", "10"}]}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", " ", "1", ",", " ", 
         RowBox[{"Length", "[", "tablatube", "]"}]}], "}"}]}], "]"}]}]}], ",",
    " ", "\n", "  ", 
   RowBox[{"{", 
    RowBox[{"ii", ",", " ", "1", ",", " ", 
     RowBox[{
      RowBox[{"Length", "[", "posicionestot", "]"}], "/", "np"}], ",", " ", 
     "1"}], "}"}]}], "]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"listaenergia", " ", "=", " ", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"radio", "[", "ii", "]"}], ",", " ", 
        RowBox[{"energia", "[", "ii", "]"}]}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"ii", ",", " ", "1", ",", " ", 
        RowBox[{
         RowBox[{"Length", "[", "posicionestot", "]"}], "/", "np"}]}], 
       "}"}]}], "]"}]}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"c", " ", "=", " ", 
    RowBox[{"ColorData", "[", "\"\<SouthwestColors\>\"", "]"}]}], ";"}], 
  " "}], "\n", 
 RowBox[{"Animate", "[", 
  RowBox[{
   RowBox[{"GraphicsGrid", "[", "\n", "   ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Graphics3D", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"RGBColor", "[", 
                 RowBox[{"0", ",", " ", "1", ",", " ", "0"}], "]"}], ",", " ", 
                RowBox[{"Opacity", "[", "0.5", "]"}], ",", " ", "\n", 
                "         ", 
                RowBox[{"Sphere", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}], ",", 
                  " ", 
                  RowBox[{"radio", "[", "ii", "]"}]}], "]"}]}], "}"}], ",", 
              " ", 
              RowBox[{"Boxed", " ", "->", " ", "False"}], ",", " ", 
              RowBox[{"PlotLabel", " ", "->", " ", 
               RowBox[{"Row", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<Particles=\>\"", ",", " ", "np"}], "}"}], 
                "]"}]}]}], "]"}], ",", " ", 
            RowBox[{"Graphics3D", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"RGBColor", "[", 
                 RowBox[{"0", ",", " ", "0.5", ",", " ", "1"}], "]"}], ",", 
                " ", 
                RowBox[{"coresmall", "[", "ii", "]"}]}], "}"}], ",", " ", 
              RowBox[{"Boxed", " ", "->", " ", "False"}]}], "]"}], ",", " ", 
            "\n", "       ", 
            RowBox[{"Graphics3D", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"RGBColor", "[", 
                 RowBox[{"0", ",", " ", "0.5", ",", " ", "1"}], "]"}], ",", 
                " ", 
                RowBox[{"Opacity", "[", "0.0", "]"}], ",", " ", 
                RowBox[{"coronasmall", "[", "ii", "]"}]}], "}"}], ",", " ", 
              RowBox[{"Boxed", " ", "->", " ", "False"}]}], "]"}], ",", " ", 
            "\n", "       ", 
            RowBox[{"Graphics3D", "[", 
             RowBox[{"tubos", "[", "ii", "]"}], "]"}]}], "}"}], ",", " ", 
          RowBox[{"PlotRange", " ", "->", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "radioinicial"}], " ", "-", " ", 
                RowBox[{"sigma1", "/", "2"}]}], ",", " ", 
               RowBox[{"radioinicial", " ", "+", " ", 
                RowBox[{"sigma1", "/", "2"}]}]}], "}"}], ",", " ", "\n", 
             "        ", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "radioinicial"}], " ", "-", " ", 
                RowBox[{"sigma1", "/", "2"}]}], ",", " ", 
               RowBox[{"radioinicial", " ", "+", " ", 
                RowBox[{"sigma1", "/", "2"}]}]}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "radioinicial"}], " ", "-", " ", 
                RowBox[{"sigma1", "/", "2"}]}], ",", " ", "\n", "         ", 
               RowBox[{"radioinicial", " ", "+", " ", 
                RowBox[{"sigma1", "/", "2"}]}]}], "}"}]}], "}"}]}], ",", " ", 
          
          RowBox[{"AspectRatio", " ", "->", " ", "Automatic"}], ",", " ", 
          "\n", "      ", 
          RowBox[{"Epilog", " ", "->", " ", 
           RowBox[{"Inset", "[", 
            RowBox[{
             RowBox[{"Text", "[", 
              RowBox[{"TextGrid", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"\"\<Step:\>\"", ",", " ", "ii"}], "}"}], ",", " ", 
                 
                 RowBox[{"{", 
                  RowBox[{"\"\<Radius:\>\"", ",", " ", 
                   RowBox[{"radio", "[", "ii", "]"}]}], "}"}], ",", " ", "\n",
                  "           ", 
                 RowBox[{"{", 
                  RowBox[{"\"\<Energy:\>\"", ",", " ", 
                   RowBox[{"energia", "[", "ii", "]"}]}], "}"}]}], "}"}], 
               "]"}], "]"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"Left", ",", " ", "Top"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"Left", ",", " ", "Top"}], "}"}]}], "]"}]}]}], "]"}], 
        ",", " ", "\n", "     ", 
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{"ListPlot", "[", 
           RowBox[{"listaenergia", ",", " ", 
            RowBox[{"Frame", " ", "->", " ", "True"}], ",", " ", 
            RowBox[{"FrameLabel", " ", "->", " ", 
             RowBox[{"{", 
              RowBox[{"Radius", ",", " ", "Energy"}], "}"}]}]}], "]"}], ",", 
          " ", "\n", "      ", 
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"PointSize", "[", "Large", "]"}], ",", " ", 
             RowBox[{"RGBColor", "[", 
              RowBox[{
              "0.922526", ",", " ", "0.385626", ",", " ", "0.209179"}], "]"}],
              ",", " ", "\n", "        ", 
             RowBox[{"Point", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"radio", "[", "ii", "]"}], ",", " ", 
                RowBox[{"energia", "[", "ii", "]"}]}], "}"}], "]"}]}], "}"}], 
           "]"}]}], "]"}]}], "}"}], "}"}], ",", " ", 
     RowBox[{"ImageSize", " ", "->", " ", 
      RowBox[{"{", 
       RowBox[{"870", ",", " ", "400"}], "}"}]}]}], "]"}], ",", " ", "\n", 
   "  ", 
   RowBox[{"{", 
    RowBox[{"ii", ",", " ", "1", ",", " ", 
     RowBox[{
      RowBox[{"Length", "[", "posicionestot", "]"}], "/", "np"}], ",", " ", 
     "1", ",", " ", 
     RowBox[{"AppearanceElements", " ", "->", " ", 
      RowBox[{"{", 
       RowBox[{
       "\"\<ProgressSlider\>\"", ",", " ", "\"\<StepLeftButton\>\"", ",", " ",
         "\n", "     ", "\"\<StepRightButton\>\"", ",", " ", 
        "\"\<PlayPauseButton\>\"", ",", " ", "\"\<FasterSlowerButtons\>\"", 
        ",", " ", "\"\<DirectionButton\>\""}], "}"}]}]}], "}"}], ",", " ", 
   "\n", "  ", 
   RowBox[{"AnimationRunning", " ", "->", " ", "False"}], ",", " ", 
   RowBox[{"DisplayAllSteps", " ", "->", " ", "True"}]}], "]"}], "\n", 
 RowBox[{"Animate", "[", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Graphics3D", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"RGBColor", "[", 
            RowBox[{"0", ",", " ", "1", ",", " ", "0"}], "]"}], ",", " ", 
           RowBox[{"Opacity", "[", "0.6", "]"}], ",", " ", "\n", "         ", 
           
           RowBox[{"Sphere", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}], ",", " ", 
             RowBox[{
              RowBox[{"radio", "[", "ii", "]"}], "-", "0.1"}]}], "]"}]}], 
          "}"}], ",", " ", 
         RowBox[{"Boxed", " ", "->", " ", "False"}]}], "]"}], ",", 
       RowBox[{"Graphics3D", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"RGBColor", "[", 
            RowBox[{"0", ",", " ", "0.5", ",", " ", "1"}], "]"}], ",", " ", 
           RowBox[{"coresmall", "[", "ii", "]"}]}], "}"}], ",", " ", 
         RowBox[{"Boxed", " ", "->", " ", "False"}]}], "]"}], ",", 
       RowBox[{"Graphics3D", "[", 
        RowBox[{"tubos", "[", "ii", "]"}], "]"}]}], "}"}], ",", " ", 
     RowBox[{"PlotRange", " ", "->", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "radioinicial"}], " ", "-", " ", 
           RowBox[{"sigma1", "/", "2"}]}], ",", " ", 
          RowBox[{"radioinicial", " ", "+", " ", 
           RowBox[{"sigma1", "/", "2"}]}]}], "}"}], ",", " ", "\n", 
        "        ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "radioinicial"}], " ", "-", " ", 
           RowBox[{"sigma1", "/", "2"}]}], ",", " ", 
          RowBox[{"radioinicial", " ", "+", " ", 
           RowBox[{"sigma1", "/", "2"}]}]}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "radioinicial"}], " ", "-", " ", 
           RowBox[{"sigma1", "/", "2"}]}], ",", " ", "\n", "         ", 
          RowBox[{"radioinicial", " ", "+", " ", 
           RowBox[{"sigma1", "/", "2"}]}]}], "}"}]}], "}"}]}], ",", " ", 
     RowBox[{"AspectRatio", " ", "->", " ", "Automatic"}], ",", " ", "\n", 
     "      ", 
     RowBox[{"Epilog", " ", "->", " ", 
      RowBox[{"Inset", "[", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"TextGrid", "[", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"\"\<Step:\>\"", ",", " ", "ii"}], "}"}], "}"}], "]"}], 
         "]"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"Left", ",", " ", "Top"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"Left", ",", " ", "Top"}], "}"}]}], "]"}]}]}], "]"}], ",", 
   " ", "\n", "  ", 
   RowBox[{"{", 
    RowBox[{"ii", ",", " ", "1", ",", " ", 
     RowBox[{
      RowBox[{"Length", "[", "posicionestot", "]"}], "/", "np"}], ",", " ", 
     "1", ",", " ", 
     RowBox[{"AppearanceElements", " ", "->", " ", 
      RowBox[{"{", 
       RowBox[{
       "\"\<ProgressSlider\>\"", ",", " ", "\"\<StepLeftButton\>\"", ",", " ",
         "\n", "     ", "\"\<StepRightButton\>\"", ",", " ", 
        "\"\<PlayPauseButton\>\"", ",", " ", "\"\<FasterSlowerButtons\>\"", 
        ",", " ", "\"\<DirectionButton\>\""}], "}"}]}]}], "}"}], ",", " ", 
   "\n", "  ", 
   RowBox[{"AnimationRunning", " ", "->", " ", "False"}], ",", " ", 
   RowBox[{"DisplayAllSteps", " ", "->", " ", "True"}]}], "]"}]}], "Code",
 CellChangeTimes->{{3.419636963354*^9, 3.419636972349*^9}, {3.419637068178*^9,
    3.419637068321*^9}, {3.419642393135*^9, 3.419642418385*^9}, {
   3.41964249583*^9, 3.419642508802*^9}, {3.6416542692636642`*^9, 
   3.6416542726686687`*^9}, {3.641654359951119*^9, 3.641654379033895*^9}, {
   3.6416544334356623`*^9, 3.6416544610762577`*^9}, {3.641654516827491*^9, 
   3.641654578472898*^9}, {3.64165462967896*^9, 3.641654646069099*^9}, 
   3.641654712664918*^9, {3.6416548324648848`*^9, 3.641654877654443*^9}, {
   3.641654929456809*^9, 3.641655020728754*^9}, {3.641655158625901*^9, 
   3.641655176533655*^9}, {3.641655461543594*^9, 3.6416554877171164`*^9}, {
   3.641834571628647*^9, 3.641834657088581*^9}, {3.641835046737404*^9, 
   3.641835048012496*^9}, {3.6418388326336823`*^9, 3.64183883444372*^9}, {
   3.6418389032297688`*^9, 3.6418389051721*^9}, {3.641838946056223*^9, 
   3.6418389473585253`*^9}, {3.64185998704979*^9, 3.641859989193738*^9}, {
   3.641860071746625*^9, 3.6418602224603024`*^9}, 3.643749076906664*^9, {
   3.644002964743363*^9, 3.644002964921833*^9}, {3.7373185247264223`*^9, 
   3.737318530195348*^9}, {3.737318615421032*^9, 3.737318762937858*^9}, {
   3.737318797775609*^9, 3.7373189186243134`*^9}, {3.737318949536622*^9, 
   3.7373190001941767`*^9}, {3.737319540749673*^9, 3.7373195410142612`*^9}, {
   3.737319813738894*^9, 3.737319854736649*^9}, {3.737319939405203*^9, 
   3.737319970049715*^9}, {3.737382570109928*^9, 3.737382602930249*^9}, 
   3.7373960884060373`*^9, {3.737397419793106*^9, 3.73739742076101*^9}, {
   3.737397514092608*^9, 3.737397529308099*^9}, {3.737397750380026*^9, 
   3.7373977509448233`*^9}, {3.737469768267301*^9, 3.7374697937755203`*^9}, {
   3.7374698751619473`*^9, 3.737469880411619*^9}, {3.737470016698948*^9, 
   3.737470036202794*^9}, {3.7374700708968163`*^9, 3.73747010719888*^9}, {
   3.737470173628883*^9, 3.73747019112259*^9}, {3.738111106025762*^9, 
   3.738111106322344*^9}, 3.738113524140525*^9, 3.738114451527446*^9, {
   3.7401905436206007`*^9, 3.74019055280077*^9}, {3.740190603997937*^9, 
   3.740190607749913*^9}, {3.740190678858491*^9, 3.740190731129771*^9}, {
   3.740190802664255*^9, 3.7401908056904078`*^9}, {3.740190905529935*^9, 
   3.740190945284833*^9}, 3.740191023274107*^9, {3.740191055518436*^9, 
   3.740191065329286*^9}, {3.7401911796225*^9, 3.740191182029643*^9}, {
   3.740191223065174*^9, 3.740191251429364*^9}, {3.740191318669997*^9, 
   3.7401913606219597`*^9}, {3.740191398356482*^9, 3.740191399534853*^9}, {
   3.740191461087902*^9, 3.74019146151484*^9}, {3.740191537397566*^9, 
   3.740191537912181*^9}, {3.740191764200552*^9, 3.740191766033826*^9}, {
   3.74019245590173*^9, 3.740192459558565*^9}, {3.7402090132485228`*^9, 
   3.7402090140246897`*^9}, {3.740209198551194*^9, 3.740209221282349*^9}, {
   3.74020925268921*^9, 3.740209326617546*^9}, {3.7402094674716587`*^9, 
   3.740209494293785*^9}, 3.740209527921404*^9, {3.7402096338748083`*^9, 
   3.7402096780451937`*^9}, {3.740209728406619*^9, 3.740209748829853*^9}, 
   3.7402098280473843`*^9, {3.7402098700172043`*^9, 3.740209901202211*^9}, {
   3.740210089371859*^9, 3.7402101263764687`*^9}, {3.740210186918659*^9, 
   3.7402101876498404`*^9}, {3.740210268777357*^9, 3.7402102977844563`*^9}, {
   3.740210348913053*^9, 3.740210375124899*^9}, {3.740210441371738*^9, 
   3.7402104733844643`*^9}, {3.7402105057285357`*^9, 3.7402105450591927`*^9}, 
   3.740210622064404*^9, {3.740210669697522*^9, 3.740210789469214*^9}, {
   3.740210854168522*^9, 3.74021088175788*^9}, {3.7402109678430767`*^9, 
   3.740210968852654*^9}, 3.740211203183343*^9, {3.740211248846472*^9, 
   3.740211271236236*^9}, {3.740211350276664*^9, 3.74021136017346*^9}, {
   3.740211413245865*^9, 3.740211414540453*^9}, 3.740211486432259*^9, {
   3.740211526272081*^9, 3.7402115291835737`*^9}, {3.740213734107366*^9, 
   3.740213735964386*^9}, {3.740215378268199*^9, 3.740215378893663*^9}, {
   3.740215484469307*^9, 3.7402155084734488`*^9}, {3.740215538795394*^9, 
   3.740215539134921*^9}, {3.7402156110116053`*^9, 3.740215613087446*^9}, {
   3.740215697673822*^9, 3.740215705640418*^9}, {3.740216145377789*^9, 
   3.7402161471401453`*^9}, {3.740272950767473*^9, 3.7402730083658733`*^9}, {
   3.740360443186811*^9, 3.74036047223668*^9}, {3.740360533309535*^9, 
   3.7403605341779947`*^9}, {3.740360747707349*^9, 3.7403607552644997`*^9}, {
   3.740393089484871*^9, 3.7403932718742456`*^9}, {3.7403939818674183`*^9, 
   3.740394002519477*^9}, {3.7403940499749117`*^9, 3.740394050364666*^9}, {
   3.740394359204711*^9, 3.7403944080672817`*^9}, {3.740395949669581*^9, 
   3.740395964726775*^9}, {3.7403960024756107`*^9, 3.740396005634798*^9}, {
   3.740396042510016*^9, 3.740396047132783*^9}, {3.740417720921782*^9, 
   3.7404177414752617`*^9}, {3.740422060461391*^9, 3.740422101312402*^9}, {
   3.740424142423485*^9, 3.740424144111533*^9}, {3.740446936668948*^9, 
   3.740446943858371*^9}, {3.740527015270224*^9, 3.7405270168870707`*^9}, {
   3.740574430130323*^9, 3.740574441881501*^9}, {3.789228427280365*^9, 
   3.789228447386896*^9}, {3.789267113880471*^9, 3.789267114048452*^9}, {
   3.789268014112891*^9, 3.789268014267658*^9}, {3.789268190540618*^9, 
   3.789268190681563*^9}, {3.789268339777142*^9, 3.789268339944193*^9}, {
   3.7892691043783913`*^9, 3.789269104552678*^9}, {3.789301958780785*^9, 
   3.789301958932129*^9}, 3.789323086421715*^9, {3.78932320083877*^9, 
   3.789323201108182*^9}, {3.789347370507622*^9, 3.789347371022284*^9}, {
   3.7893477331996117`*^9, 3.7893477336106997`*^9}, {3.789347769964436*^9, 
   3.789347770152944*^9}, {3.791831222016708*^9, 3.7918312285939283`*^9}, {
   3.791831650989856*^9, 3.7918316512116632`*^9}, {3.791832048385092*^9, 
   3.7918320485906*^9}, {3.791832179666642*^9, 3.7918321845961018`*^9}, {
   3.7918327503345957`*^9, 3.7918327519488783`*^9}, {3.7918563897567472`*^9, 
   3.791856389864739*^9}, {3.7918566473980293`*^9, 3.7918566475509*^9}, {
   3.791856745630167*^9, 3.791856745786862*^9}, {3.791856875399459*^9, 
   3.791856877813581*^9}, {3.791857003368732*^9, 3.7918570034864397`*^9}, {
   3.791857160176505*^9, 3.791857160322955*^9}, {3.791908268246683*^9, 
   3.791908279662891*^9}, {3.791913770028912*^9, 3.791913778678151*^9}, {
   3.791914325468094*^9, 3.791914325590629*^9}, {3.827689454677351*^9, 
   3.827689478623611*^9}, 3.8297649530538273`*^9, {3.8297652634512777`*^9, 
   3.829765263910458*^9}, {3.829768094828719*^9, 3.829768095056036*^9}, {
   3.8297690936614847`*^9, 3.829769093785677*^9}, {3.829770069138427*^9, 
   3.829770072875243*^9}, {3.82977073435116*^9, 3.8297707374154263`*^9}, {
   3.829773072867854*^9, 3.829773073152872*^9}, {3.829773449699946*^9, 
   3.8297734500106163`*^9}, {3.829775246074892*^9, 3.829775249377617*^9}, {
   3.82977840766201*^9, 3.829778407839766*^9}, {3.829781076042407*^9, 
   3.8297810764024067`*^9}, {3.829783511541024*^9, 3.829783513803121*^9}, {
   3.8297839494263077`*^9, 3.829783949630107*^9}, {3.829785057312743*^9, 
   3.829785057539989*^9}, {3.829785408869775*^9, 3.829785436613867*^9}, {
   3.8298685158183804`*^9, 3.8298685164809523`*^9}, {3.829868851030225*^9, 
   3.8298688513948097`*^9}, {3.829869244137104*^9, 3.829869244231688*^9}, {
   3.830061208729621*^9, 3.830061209870853*^9}, {3.8300990149340277`*^9, 
   3.830099015246242*^9}, {3.830099089184868*^9, 3.830099089391657*^9}, {
   3.830126238298772*^9, 3.830126238530664*^9}, {3.8301269662245092`*^9, 
   3.830126968126128*^9}, {3.830127513116253*^9, 3.830127514130706*^9}, {
   3.830127818923324*^9, 3.830127819124901*^9}, {3.8301283564454613`*^9, 
   3.830128356875794*^9}, {3.830298835350895*^9, 3.8302988485914307`*^9}, {
   3.831292402336035*^9, 3.831292406022872*^9}, {3.831292692215446*^9, 
   3.831292693007928*^9}, {3.831325283184392*^9, 3.831325283673214*^9}, {
   3.831340749470359*^9, 3.831340749952755*^9}, {3.831369238556233*^9, 
   3.831369238684843*^9}, {3.8313725228892736`*^9, 3.831372523006542*^9}, {
   3.8314248073852262`*^9, 3.8314248086866817`*^9}, {3.8316504584014*^9, 
   3.8316504589411097`*^9}, {3.831653287147468*^9, 3.831653287474328*^9}, {
   3.831683004626845*^9, 3.831683004922771*^9}, {3.831684850472477*^9, 
   3.831684850643268*^9}, {3.831713325250224*^9, 3.831713325371519*^9}, {
   3.832266499484911*^9, 3.832266501817416*^9}, 3.832266593572008*^9, {
   3.8322668193518953`*^9, 3.832266819873843*^9}, {3.832267046850902*^9, 
   3.832267047007379*^9}, {3.832267193467379*^9, 3.832267200118927*^9}, {
   3.832267570457879*^9, 3.832267570675581*^9}, {3.832267704062387*^9, 
   3.832267704156355*^9}, {3.832268041598632*^9, 3.8322680416388206`*^9}, {
   3.8322681762177553`*^9, 3.832268176408765*^9}, {3.832268338425962*^9, 
   3.8322683389263372`*^9}, {3.8322684597038717`*^9, 3.832268460077929*^9}, {
   3.832268632995084*^9, 3.832268633174362*^9}, {3.832268996157037*^9, 
   3.8322689966096992`*^9}, {3.832271338865192*^9, 3.832271338975559*^9}, {
   3.8322749771722393`*^9, 3.832274979435007*^9}, {3.8322791476673203`*^9, 
   3.832279148241438*^9}, {3.8322796486906443`*^9, 3.832279649150498*^9}, {
   3.832279740475507*^9, 3.832279740954471*^9}, {3.832354749637348*^9, 
   3.832354749809616*^9}, {3.832354887197407*^9, 3.832354887477551*^9}, {
   3.832354920119401*^9, 3.8323549754288683`*^9}, {3.832355374793085*^9, 
   3.8323553752325897`*^9}, {3.8323568934318857`*^9, 3.832356927790762*^9}, {
   3.8323569594074717`*^9, 3.832356959722625*^9}, {3.832356992539323*^9, 
   3.832357057473489*^9}, {3.8323579754296923`*^9, 3.8323580187523613`*^9}, {
   3.832361439603508*^9, 3.8323614397796173`*^9}, {3.832362961806904*^9, 
   3.832362962167226*^9}, {3.832366281492814*^9, 3.832366308660183*^9}, {
   3.8323671974424753`*^9, 3.832367197602174*^9}, {3.83237528215598*^9, 
   3.832375282540393*^9}, {3.832378990858418*^9, 3.832378991079482*^9}, {
   3.832410123399026*^9, 3.832410123610469*^9}, {3.832411293671707*^9, 
   3.832411294081674*^9}, {3.832416786186805*^9, 3.832416786503161*^9}, {
   3.832416822394218*^9, 3.832416822556553*^9}, {3.832421290404607*^9, 
   3.8324212918829947`*^9}, {3.832446759758912*^9, 3.832446760647821*^9}, {
   3.8324474307424517`*^9, 3.832447430939816*^9}, {3.832894462526884*^9, 
   3.832894462890397*^9}, {3.832968158380498*^9, 3.832968161306787*^9}, {
   3.8329701158912897`*^9, 3.832970118136642*^9}, {3.832976432986014*^9, 
   3.832976433519034*^9}, {3.8330340814727993`*^9, 3.833034081894751*^9}, {
   3.8330343691051083`*^9, 3.833034371054967*^9}, {3.833034437233485*^9, 
   3.8330344397661257`*^9}, {3.833066294413966*^9, 3.8330662949177437`*^9}, {
   3.833109819328065*^9, 3.8331098197217817`*^9}, {3.860622850537304*^9, 
   3.8606228751801367`*^9}, {3.860690542993724*^9, 3.860690591346868*^9}, {
   3.860703831434478*^9, 3.8607038472839727`*^9}, {3.860707693450151*^9, 
   3.8607076947251577`*^9}, {3.860708393983377*^9, 3.8607083974093533`*^9}, {
   3.8607087049196978`*^9, 3.860708708673305*^9}, {3.8607186269834414`*^9, 
   3.860718629572741*^9}, 3.860718884169915*^9, {3.860742027499916*^9, 
   3.86074202816448*^9}, {3.860743395876967*^9, 3.860743400866646*^9}, {
   3.8607486481066933`*^9, 3.860748648745697*^9}, {3.860915061341929*^9, 
   3.8609150620191298`*^9}, {3.860915209313807*^9, 3.860915209485737*^9}, {
   3.860915277876668*^9, 3.8609152780045233`*^9}, {3.860916454919662*^9, 
   3.860916455114255*^9}, {3.8609165164605913`*^9, 3.8609165178662558`*^9}, {
   3.860917269981736*^9, 3.860917272977956*^9}, {3.8609310074255257`*^9, 
   3.860931043512141*^9}, 3.860950767701034*^9, {3.860950812107473*^9, 
   3.860950829954879*^9}, {3.8610407252642717`*^9, 3.8610407284030447`*^9}, {
   3.861040831618511*^9, 3.8610408323321867`*^9}, {3.86109007992206*^9, 
   3.861090080348827*^9}, {3.861095248722638*^9, 3.8610952492825317`*^9}, {
   3.861101641317609*^9, 3.861101641423854*^9}, {3.861161809234185*^9, 
   3.861161809472261*^9}, {3.8611627401381683`*^9, 3.861162740377245*^9}, {
   3.861209436942144*^9, 3.8612094376008663`*^9}, {3.861210408556222*^9, 
   3.861210410207129*^9}, {3.861210812837538*^9, 3.861210813155076*^9}, {
   3.861212705248225*^9, 3.8612127063998528`*^9}, {3.8612285715747423`*^9, 
   3.8612285724876947`*^9}, {3.861266670504121*^9, 3.861266670619969*^9}, {
   3.8612816715668364`*^9, 3.861281672256068*^9}, {3.861294317103282*^9, 
   3.86129432274613*^9}, 3.861295349000149*^9, {3.861308085134079*^9, 
   3.86130808553481*^9}, {3.861310524775012*^9, 3.861310525029676*^9}, {
   3.861311214221489*^9, 3.861311214481455*^9}, {3.861312482896064*^9, 
   3.861312483058834*^9}, {3.8613132595899897`*^9, 3.861313259701715*^9}, {
   3.861314679485939*^9, 3.861314680199974*^9}, {3.8613162515736856`*^9, 
   3.861316251689052*^9}, {3.861316755440715*^9, 3.861316756275484*^9}, {
   3.86131748259128*^9, 3.861317483751133*^9}, {3.861321390276081*^9, 
   3.861321390982802*^9}, {3.8613870952155743`*^9, 3.861387095777555*^9}, {
   3.8613898399625196`*^9, 3.861389843964861*^9}, {3.8613903815570917`*^9, 
   3.861390382142803*^9}, {3.861392529239315*^9, 3.8613925341678658`*^9}, {
   3.861442152981052*^9, 3.8614421768776083`*^9}, {3.8614422207374268`*^9, 
   3.861442221223722*^9}, {3.861481738196294*^9, 3.8614817448773537`*^9}, {
   3.861483367687131*^9, 3.861483368278263*^9}, {3.861483534041396*^9, 
   3.861483535086035*^9}, {3.8614843753507767`*^9, 3.8614843760863533`*^9}, {
   3.861484509503207*^9, 3.861484509905138*^9}, {3.861484742547461*^9, 
   3.861484749244741*^9}, {3.861532633666297*^9, 3.861532638613669*^9}, {
   3.8615381311151953`*^9, 3.861538131591037*^9}, {3.861538488617085*^9, 
   3.861538489071795*^9}, {3.86178714227705*^9, 3.861787173084022*^9}, {
   3.861787334088903*^9, 3.8617873343002567`*^9}, {3.86178762045207*^9, 
   3.861787620602157*^9}, {3.86178775108062*^9, 3.8617877513953123`*^9}, {
   3.861787793920779*^9, 3.861787794564108*^9}, {3.861787848597156*^9, 
   3.861787849196636*^9}, {3.861790321381281*^9, 3.861790321916526*^9}, {
   3.8617905886742287`*^9, 3.8617905905087013`*^9}, {3.861831794530889*^9, 
   3.8618317947349586`*^9}, {3.863713941115699*^9, 3.863713945137249*^9}, {
   3.864511362443986*^9, 3.8645113626889353`*^9}, {3.864646483163144*^9, 
   3.8646464833145847`*^9}, {3.864691281595311*^9, 3.864691284198292*^9}, {
   3.8647367550551233`*^9, 3.8647367559067173`*^9}, {3.864770619800188*^9, 
   3.864770620309622*^9}, {3.864798684419195*^9, 3.864798684986491*^9}, {
   3.864816965110896*^9, 3.864816966211417*^9}, {3.8648914661123343`*^9, 
   3.8648914689381237`*^9}, {3.864898437727056*^9, 3.864898437802743*^9}, {
   3.8649145958070374`*^9, 3.8649145985942183`*^9}, {3.8649246454921427`*^9, 
   3.864924648095974*^9}, {3.8649460318921843`*^9, 3.864946032037117*^9}, {
   3.86494640817281*^9, 3.864946408924507*^9}, {3.8649794579739313`*^9, 
   3.8649794602957287`*^9}, {3.864979949567234*^9, 3.864979953811811*^9}, {
   3.8649807609061623`*^9, 3.864980789019226*^9}, {3.8649826795581217`*^9, 
   3.864982679738976*^9}, {3.8649988507029543`*^9, 3.86499886698409*^9}, {
   3.865008319603298*^9, 3.865008337878265*^9}, {3.865021814751618*^9, 
   3.86502181486392*^9}, 3.86502377544209*^9, {3.865071371918193*^9, 
   3.865071373628276*^9}, {3.86507948777527*^9, 3.865079489551095*^9}, {
   3.865133295071336*^9, 3.865133297367806*^9}, 3.8651725527088127`*^9, 
   3.8651795107478848`*^9, 3.865183535831277*^9, {3.865241736583365*^9, 
   3.865241738036981*^9}, {3.865280769001758*^9, 3.865280796954315*^9}, {
   3.86528211982757*^9, 3.8652821413181667`*^9}, 3.865282571088718*^9, {
   3.865282978718053*^9, 3.865282990040862*^9}, 3.865322864596339*^9, {
   3.865368116590382*^9, 3.8653681167784653`*^9}, {3.865417373004793*^9, 
   3.865417373254951*^9}, 3.865446129275592*^9, {3.8654657399699783`*^9, 
   3.8654657422981243`*^9}, {3.8654660820467377`*^9, 3.865466082980596*^9}, {
   3.8654662724583607`*^9, 3.8654662726612387`*^9}, {3.8654666681022882`*^9, 
   3.865466668571107*^9}, {3.865467441921471*^9, 3.865467442517468*^9}, {
   3.865467593779038*^9, 3.865467594142679*^9}, {3.865505061654901*^9, 
   3.865505067891757*^9}, {3.8655208792177277`*^9, 3.8655208796803637`*^9}, {
   3.8655235451007757`*^9, 3.865523547247613*^9}, {3.865572181252496*^9, 
   3.86557218166041*^9}, {3.865572564831932*^9, 3.865572565822998*^9}, {
   3.865593214919449*^9, 3.86559321736129*^9}, {3.8656033767906427`*^9, 
   3.8656033769943733`*^9}, {3.8656105168504457`*^9, 
   3.8656105191048727`*^9}, {3.865610568141364*^9, 3.8656105687583847`*^9}, {
   3.865634264961584*^9, 3.865634269359778*^9}, {3.8656343053109283`*^9, 
   3.865634306025928*^9}, {3.865639798506133*^9, 3.8656398186638117`*^9}, {
   3.8656398949652643`*^9, 3.865639897397183*^9}, {3.865642359380671*^9, 
   3.865642381642123*^9}, {3.865642419637038*^9, 3.865642419780447*^9}, {
   3.865643813631147*^9, 3.865643816813757*^9}, {3.865644263778543*^9, 
   3.8656442661125813`*^9}, {3.8656780580802794`*^9, 3.865678058627572*^9}, {
   3.8656792981226673`*^9, 3.8656792982698793`*^9}, {3.8656796598578787`*^9, 
   3.8656796603562403`*^9}, {3.865685727062277*^9, 3.865685730211549*^9}, 
   3.8656859279599857`*^9, {3.865686884791649*^9, 3.865686887308278*^9}, {
   3.8656883170911922`*^9, 3.86568831967811*^9}, {3.865690131367703*^9, 
   3.865690133418481*^9}, {3.865692512796157*^9, 3.865692513424635*^9}, {
   3.865693454773394*^9, 3.865693454924*^9}, {3.865694427808148*^9, 
   3.8656944299251347`*^9}, {3.865695111415694*^9, 3.86569511189472*^9}, {
   3.8656953355420227`*^9, 3.865695337839142*^9}, {3.865695734804167*^9, 
   3.865695735511113*^9}, {3.8656967152507544`*^9, 3.8656967165502377`*^9}, {
   3.865697571410323*^9, 3.865697573303913*^9}, {3.865698364023387*^9, 
   3.865698368212078*^9}, {3.865699667823794*^9, 3.865699668168976*^9}, {
   3.865702134911195*^9, 3.865702138305008*^9}, {3.865702519866982*^9, 
   3.865702521186307*^9}, {3.86570288789223*^9, 3.865702888483309*^9}, {
   3.865703365602159*^9, 3.865703387699275*^9}, {3.865703428012439*^9, 
   3.86570347246208*^9}, {3.865703507518886*^9, 3.865703508780157*^9}, {
   3.8657035503477173`*^9, 3.865703550773353*^9}, {3.865704304556025*^9, 
   3.86570430482865*^9}, {3.865704874023745*^9, 3.865704874183374*^9}, {
   3.865705508025228*^9, 3.865705508473001*^9}, {3.86570613790942*^9, 
   3.8657061384005938`*^9}, {3.865706584727415*^9, 3.865706586066093*^9}, {
   3.865708213972003*^9, 3.865708214517899*^9}, {3.865709128154469*^9, 
   3.86570912899188*^9}, {3.865709881308114*^9, 3.8657098820912657`*^9}, {
   3.865710170071291*^9, 3.865710173081704*^9}, {3.865710751671487*^9, 
   3.865710752670478*^9}, 3.865711483957827*^9, {3.8657116893521433`*^9, 
   3.865711689543425*^9}, {3.865712058413334*^9, 3.8657120585491457`*^9}, {
   3.8657123170145273`*^9, 3.8657123171495333`*^9}, {3.865712460649212*^9, 
   3.865712461040634*^9}, {3.8657129444488077`*^9, 3.86571294461854*^9}, {
   3.865713699891227*^9, 3.8657137001678867`*^9}, {3.865713791711755*^9, 
   3.865713792274294*^9}, {3.865713941940403*^9, 3.865713942073648*^9}, {
   3.865714768244512*^9, 3.865714768443551*^9}, {3.8657148199783297`*^9, 
   3.8657148201719847`*^9}, 3.8657162362162323`*^9, {3.865716267067769*^9, 
   3.865716267402269*^9}, {3.86572022262929*^9, 3.865720223064004*^9}, {
   3.8657584490698023`*^9, 3.865758454750081*^9}, {3.865759133781892*^9, 
   3.8657591362689533`*^9}, {3.865759167426098*^9, 3.865759169165441*^9}, {
   3.8657592350260077`*^9, 3.8657592357425213`*^9}, {3.865760899726514*^9, 
   3.865760900057229*^9}, {3.865761639300357*^9, 3.865761654596169*^9}, {
   3.8657937217957697`*^9, 3.865793727002038*^9}, {3.865851118261858*^9, 
   3.8658511187919703`*^9}, {3.865854642494938*^9, 3.8658546722755003`*^9}, {
   3.865854784116828*^9, 3.865854788080735*^9}, {3.8658548426621523`*^9, 
   3.865854842870741*^9}, {3.865855129550508*^9, 3.865855129764144*^9}, {
   3.865857522740967*^9, 3.8658575245185204`*^9}, {3.8658575743889303`*^9, 
   3.865857574684012*^9}, {3.8658585813503942`*^9, 3.865858581483036*^9}, {
   3.865862516525923*^9, 3.865862518683896*^9}, 3.866520111070862*^9, 
   3.866520544419775*^9, {3.8665209916086693`*^9, 3.8665209938741693`*^9}, {
   3.8665210836198893`*^9, 3.8665210839594917`*^9}, {3.8665212304903603`*^9, 
   3.866521233345982*^9}, {3.8665218337432537`*^9, 3.8665218376329317`*^9}, {
   3.866522410348275*^9, 3.8665225008876457`*^9}, {3.866522626066234*^9, 
   3.866522735357626*^9}, {3.866522771563287*^9, 3.866522772542321*^9}, {
   3.8665229983328667`*^9, 3.866523000707988*^9}, {3.866523529342025*^9, 
   3.866523531634832*^9}, {3.866523787970199*^9, 3.8665237882676573`*^9}, {
   3.8665239200541773`*^9, 3.866523922468082*^9}, {3.8665243478057003`*^9, 
   3.866524350121067*^9}, {3.866524628575059*^9, 3.86652462881227*^9}, {
   3.8665249793701763`*^9, 3.866524982611896*^9}, {3.866525069939702*^9, 
   3.866525077861436*^9}, {3.8665255961911917`*^9, 3.8665256011998377`*^9}, {
   3.866525960219646*^9, 3.8665259638683777`*^9}, {3.866527261538974*^9, 
   3.866527291002149*^9}, {3.866532036717431*^9, 3.866532039231325*^9}, {
   3.866532189470826*^9, 3.8665321897449923`*^9}, {3.866535203559677*^9, 
   3.866535209488879*^9}, {3.866544402534952*^9, 3.8665444085037537`*^9}, {
   3.8665451022917833`*^9, 3.866545104939361*^9}, 3.866545345000001*^9, 
   3.866545556055118*^9, {3.866545624651135*^9, 3.8665456258082952`*^9}, {
   3.866545805046421*^9, 3.866545806240265*^9}, {3.86656091847473*^9, 
   3.8665609224122763`*^9}, {3.866565637240868*^9, 3.8665656385027733`*^9}, {
   3.866685412144829*^9, 3.8666854209098883`*^9}, {3.866798962795047*^9, 
   3.866798968251973*^9}},ExpressionUUID->"28ec33d4-9e6d-4936-8f3e-\
2ab9c2099011"]
}, Open  ]]
},
WindowSize->{1133, 747},
WindowMargins->{{90, Automatic}, {Automatic, 22}},
FrontEndVersion->"13.0 para Mac OS X ARM (64-bit) (February 4, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"85ed572b-cd69-4d70-a84d-fc440c6aa972"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 1060, 18, 219, "Section",ExpressionUUID->"3ba06042-c261-486c-ab9f-45f2778dea21"],
Cell[1643, 42, 55535, 1169, 1303, "Code",ExpressionUUID->"28ec33d4-9e6d-4936-8f3e-2ab9c2099011"]
}, Open  ]]
}
]
*)

